@@ -4,21 +4,26 @@ from pickle import dump, load, HIGHEST_PROTOCOL
 from lz77c import lz77_compress
 from .huffman_coding import huffman_coding
 from .compress_util import lzhw_decompress, code_filling
-from .util import is_number
+from .util import is_number, nums
 import numpy as np
 
+
 # Putting everything together in one class
 # Lempel-Ziv-Huffman-Welch. I invented it :D
 class LZHW:
-    def __init__(self, uncompressed):
-        self._compress(uncompressed)
+    def __init__(self, uncompressed, sliding_window = 256):
+        self._compress(uncompressed, sliding_window)
 
-    def _compress(self, uncompressed):
+    def _compress(self, uncompressed, sliding_window):
         self.__original_size = getsizeof(uncompressed)
-        is_num = is_number(uncompressed[0])
+
         if not isinstance(uncompressed, np.ndarray):
             uncompressed = np.array(uncompressed)
-        if len(set(uncompressed)) / len(uncompressed) >= 0.8:
+            is_num = is_number(uncompressed[0])
+        else:
+            is_num = any(i in str(uncompressed.dtype) for i in nums)
+
+        if len(set(uncompressed)) / len(uncompressed) >= 0.75:
             self.sequences = {"lz77": True}
             self.compressed = uncompressed
         else:
